==> eslint-config-typescript-react-native-2.0.1.tgz: package/README.md <==
<p align="center">
  <br><img width="250" src="https://untile.pt/logo.png" /><br>
</p>

<h1 align="center">
  @untile/eslint-config-typescript-react-native
</h1>

<h4 align="center">
  Untile-flavored ESLint react-native config. Extends `@untile/eslint-config-typescript-react`.
</h4>

<p align="center">
  <a href="https://www.npmjs.com/package/@untile/eslint-config-typescript-react-native">
    <img
      src="https://img.shields.io/npm/v/@untile/eslint-config-typescript-react-native.svg?style=for-the-badge"
      alt="NPM version"
    />
  </a>
  <a href="https://github.com/untile/js-configs/blob/main/LICENSE">
    <img
      src="https://img.shields.io/badge/license-MIT-blue.svg?style=for-the-badge"
      alt="Untile js-config is released under the MIT license."
    />
  </a>
  <a href="https://twitter.com/intent/follow?screen_name=untiledigital">
    <img
      src="https://img.shields.io/twitter/follow/untiledigital.svg?label=Follow%20@untiledigital&style=for-the-badge"
      alt="Follow @untiledigital"
    />
  </a>
</p>

## Installation

With `npm`:

```sh
npm install eslint @untile/eslint-config-typescript-react-native --save-dev
```

Or using `yarn`:

```sh
yarn add eslint @untile/eslint-config-typescript-react-native -D
```

## Setup

Create an `.eslintrc.js` file with the following:

```js
extends: ['@untile/eslint-config-typescript-react-native']
```

## Usage

Add the following `script` to your `package.json`:

```json
{
  "scripts": {
    "lint": "eslint ."
  }
}
```

and run the linter with:

```sh
yarn lint
```

==> eslint-config-typescript-react-native-3.1.0.tgz: package/README.md <==
<p align="center">
  <br><img width="250" src="https://untile.pt/logo.png" /><br>
</p>

<h1 align="center">
  @untile/eslint-config-typescript-react-native
</h1>

<h4 align="center">
  Untile-flavored ESLint react-native config. Extends `@untile/eslint-config-typescript-react`.
</h4>

<p align="center">
  <a href="https://www.npmjs.com/package/@untile/eslint-config-typescript-react-native">
    <img
      src="https://img.shields.io/npm/v/@untile/eslint-config-typescript-react-native.svg?style=for-the-badge"
      alt="NPM version"
    />
  </a>
  <a href="https://github.com/untile/js-configs/blob/main/LICENSE">
    <img
      src="https://img.shields.io/badge/license-MIT-blue.svg?style=for-the-badge"
      alt="Untile js-config is released under the MIT license."
    />
  </a>
  <a href="https://twitter.com/intent/follow?screen_name=untiledigital">
    <img
      src="https://img.shields.io/twitter/follow/untiledigital.svg?label=Follow%20@untiledigital&style=for-the-badge"
      alt="Follow @untiledigital"
    />
  </a>
</p>

## Requirements

- Node.js >= 20
- ESLint >= 9
- TypeScript >= 4.9.0

## Installation

With `npm`:

```sh
npm install eslint @untile/eslint-config-typescript-react-native --save-dev
```

Or using `yarn`:

```sh
yarn add eslint @untile/eslint-config-typescript-react-native -D
```

## Setup

Create an `eslint.config.js` file with the following:

```js
const eslintUntileConfigTypescriptReactNative = require('@untile/eslint-config-typescript-react-native');

module.exports = eslintUntileConfigTypescriptReactNative;
```

## Usage

Add the following `script` to your `package.json`:

```json
{
  "scripts": {
    "lint": "eslint ."
  }
}
```

and run the linter with:

```sh
yarn lint
```
